@@ -4,19 +4,26 @@ use warnings;
 
 package Dist::Zilla::Plugin::Bugtracker;
 BEGIN {
-  $Dist::Zilla::Plugin::Bugtracker::VERSION = '1.101420';
+  $Dist::Zilla::Plugin::Bugtracker::VERSION = '1.101490';
 }
+
 # ABSTRACT: Automatically sets the bugtracker URL
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
 sub metadata {
     my $self = shift;
+
+    my $web = sprintf('http://rt.cpan.org/Public/Dist/Display.html?Name=%s',
+      $self->zilla->name);
+    my $mailto = sprintf('bug-%s at rt.cpan.org', lc( $self->zilla->name ) );
+
     return {
         resources => {
-            bugtracker =>
-              sprintf('http://rt.cpan.org/Public/Dist/Display.html?Name=%s',
-                $self->zilla->name)
+            bugtracker => {
+                web => $web,
+                mailto => $mailto,
+            }
         }
     };
 }
@@ -34,7 +41,7 @@ Dist::Zilla::Plugin::Bugtracker - Automatically sets the bugtracker URL
 
 =head1 VERSION
 
-version 1.101420
+version 1.101490
 
 =head1 SYNOPSIS
 
@@ -44,7 +51,14 @@ In C<dist.ini>:
 
 =head1 DESCRIPTION
 
-This plugin sets the distribution's bugtracker URL as metadata.
+This plugin sets the distribution's bugtracker URL as metadata. This plugin
+assumes you are using the CPAN RT bugtracker and sets those 2 fields:
+
+  web = http://rt.cpan.org/Public/Dist/Display.html?Name=$dist
+  mailto = bug-$dist at rt.cpan.org
+
+Please see L<CPAN::Meta::Spec|http://search.cpan.org/dist/CPAN-Meta/lib/CPAN/Meta/Spec.pm#resources>
+for more information.
 
 =head1 FUNCTIONS
 
@@ -64,7 +78,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Bugtracker>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
